@@ -21,27 +21,16 @@ import functools
 import inspect
 import json
 import logging
+import os
 import re
 import typing  # noqa: F401
 import warnings
 from copy import copy
+from decimal import Decimal
 from io import StringIO, TextIOWrapper
 from json import JSONEncoder
 from sys import version_info
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    List,
-    Optional,
-    Set,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-    cast,
-)
+from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple, Type, TypeVar, Union, cast
 from xml.etree import ElementTree
 
 if version_info >= (3, 8):
@@ -55,13 +44,16 @@ from .helpers import BaseHelper
 logger = logging.getLogger('serializable')
 logger.setLevel(logging.INFO)
 
+_F = TypeVar("_F", bound=Callable[..., Any])
+_T = TypeVar('_T', bound='_Klass')
+
 
 class _Klass(Protocol):
+    __name__: str
     __qualname__: str
 
 
-_F = TypeVar("_F", bound=Callable[..., Any])
-_T = TypeVar('_T', bound=_Klass)
+ViewType = _Klass
 
 
 @enum.unique
@@ -107,6 +99,32 @@ class XmlArraySerializationType(enum.Enum):
     NESTED = 2
 
 
+def _allow_property_for_view(prop_info: 'ObjectMetadataLibrary.SerializableProperty', value_: Any,
+                             view_: Optional[Type[_Klass]]) -> bool:
+    # First check Property is part of the View is given
+    allow_for_view = False
+    if view_:
+        if prop_info.views and view_ in prop_info.views:
+            allow_for_view = True
+        elif not prop_info.views:
+            allow_for_view = True
+    else:
+        if not prop_info.views:
+            allow_for_view = True
+
+    # Second check for inclusion of None values
+    if value_ is None or (prop_info.is_array and len(value_) < 1):
+        if not prop_info.include_none:
+            allow_for_view = False
+        elif prop_info.include_none and prop_info.include_none_views:
+            allow_for_view = False
+            for _v, _a in prop_info.include_none_views:
+                if _v == view_:
+                    allow_for_view = True
+
+    return allow_for_view
+
+
 class _SerializableJsonEncoder(JSONEncoder):
     """
     ``serializable``'s custom implementation of ``JSONEncode``.
@@ -114,6 +132,20 @@ class _SerializableJsonEncoder(JSONEncoder):
     You don't need to call this directly - it is all handled for you by ``serializable``.
     """
 
+    def __init__(self, *, skipkeys: bool = False, ensure_ascii: bool = True, check_circular: bool = True,
+                 allow_nan: bool = True, sort_keys: bool = False, indent: Optional[int] = None,
+                 separators: Optional[Tuple[str, str]] = None, default: Optional[Callable[[Any], Any]] = None,
+                 view_: Optional[Type[_Klass]] = None) -> None:
+        super().__init__(
+            skipkeys=skipkeys, ensure_ascii=ensure_ascii, check_circular=check_circular, allow_nan=allow_nan,
+            sort_keys=sort_keys, indent=indent, separators=separators, default=default
+        )
+        self._view = view_
+
+    @property
+    def view(self) -> Optional[Type[_Klass]]:
+        return self._view
+
     def default(self, o: Any) -> Any:
         # Enum
         if isinstance(o, enum.Enum):
@@ -129,43 +161,54 @@ class _SerializableJsonEncoder(JSONEncoder):
             klass_qualified_name = f'{o.__module__}.{o.__class__.__qualname__}'
             serializable_property_info = ObjectMetadataLibrary.klass_property_mappings.get(klass_qualified_name, {})
 
-            for k, v in o.__dict__.items():
-                # Exclude None values by default
-                if v is None:
+            # Handle remaining Properties that will be sub elements
+            for k, prop_info in serializable_property_info.items():
+                v = getattr(o, k)
+
+                if not _allow_property_for_view(prop_info=prop_info, view_=self._view, value_=v):
+                    # Skip as rendering for a view and this Property is not registered form this View
                     continue
 
-                # Remove leading _ in key names
-                new_key = k[1:]
-                if new_key.startswith('_') or '__' in new_key:
-                    continue
+                new_key = BaseNameFormatter.decode_handle_python_builtins_and_keywords(name=k)
 
-                if new_key in serializable_property_info:
-                    prop_info = serializable_property_info.get(new_key)
-                    if not prop_info:
-                        raise ValueError(f'Property {new_key} is not a known Property for {klass_qualified_name}')
+                if prop_info.custom_names.get(SerializationType.JSON, None):
+                    new_key = str(prop_info.custom_names.get(SerializationType.JSON))
 
-                    if prop_info.custom_name(serialization_type=SerializationType.JSON):
-                        new_key = str(prop_info.custom_name(serialization_type=SerializationType.JSON))
+                if CurrentFormatter.formatter:
+                    new_key = CurrentFormatter.formatter.encode(property_name=new_key)
 
-                    if CurrentFormatter.formatter:
-                        new_key = CurrentFormatter.formatter.encode(property_name=new_key)
-
-                    if prop_info.custom_type:
-                        if prop_info.is_helper_type():
-                            v = prop_info.custom_type.serialize(v)
+                if prop_info.custom_type:
+                    if prop_info.is_helper_type():
+                        v = prop_info.custom_type.serialize(v)
+                    else:
+                        v = prop_info.custom_type(v)
+                elif prop_info.is_array:
+                    if len(v) > 0:
+                        v = list(v)
+                    else:
+                        v = None
+                elif prop_info.is_enum:
+                    v = str(v.value)
+                elif not prop_info.is_primitive_type():
+                    if isinstance(v, Decimal):
+                        if prop_info.string_format:
+                            v = float(f'{v:{prop_info.string_format}}')
                         else:
-                            v = prop_info.custom_type(v)
-                    elif prop_info.is_enum:
-                        v = v.value
-                    elif not prop_info.is_primitive_type():
+                            v = float(v)
+                    else:
                         global_klass_name = f'{prop_info.concrete_type.__module__}.{prop_info.concrete_type.__name__}'
                         if global_klass_name not in ObjectMetadataLibrary.klass_mappings:
-                            v = str(v)
+                            if prop_info.string_format:
+                                v = f'{v:{prop_info.string_format}}'
+                            else:
+                                v = str(v)
 
-                    if CurrentFormatter.formatter:
-                        new_key = CurrentFormatter.formatter.encode(property_name=new_key)
+                if new_key == '.':
+                    return v
 
-                    d.update({new_key: v})
+                if _allow_property_for_view(prop_info=prop_info, view_=self._view, value_=v):
+                    # We need to recheck as values may have been modified above
+                    d.update({new_key: v if v is not None else prop_info.get_none_value_for_view(view_=self._view)})
 
             return d
 
@@ -173,13 +216,13 @@ class _SerializableJsonEncoder(JSONEncoder):
         super().default(o=o)
 
 
-def _as_json(self: _T) -> str:
+def _as_json(self: _T, view_: Optional[Type[Any]] = None) -> str:
     """
     Internal function that is injected into Classes that are annotated for serialization and deserialization by
     ``serializable``.
     """
-    logging.debug(f'Dumping {self} to JSON...')
-    return json.dumps(self, cls=_SerializableJsonEncoder)
+    logging.debug(f'Dumping {self} to JSON with view: {view_}...')
+    return json.dumps(self, cls=_SerializableJsonEncoder, view_=view_)
 
 
 def _from_json(cls: Type[_T], data: Dict[str, Any]) -> object:
@@ -188,13 +231,20 @@ def _from_json(cls: Type[_T], data: Dict[str, Any]) -> object:
     ``serializable``.
     """
     logging.debug(f'Rendering JSON to {cls}...')
-    klass = ObjectMetadataLibrary.klass_mappings.get(f'{cls.__module__}.{cls.__qualname__}', None)
-    klass_properties = ObjectMetadataLibrary.klass_property_mappings.get(f'{cls.__module__}.{cls.__qualname__}', {})
+    klass_qualified_name = f'{cls.__module__}.{cls.__qualname__}'
+    klass = ObjectMetadataLibrary.klass_mappings.get(klass_qualified_name, None)
+    klass_properties = ObjectMetadataLibrary.klass_property_mappings.get(klass_qualified_name, {})
 
     if klass is None:
-        warnings.warn(f'{cls.__module__}.{cls.__qualname__} is not a known serializable class')
+        warnings.warn(f'{klass_qualified_name} is not a known serializable class')
         return None
 
+    if len(klass_properties) == 1:
+        k, only_prop = next(iter(klass_properties.items()))
+        if only_prop.custom_names.get(SerializationType.JSON, None) == '.':
+            _data = {only_prop.name: data}
+            return cls(**_data)
+
     _data = copy(data)
     for k, v in data.items():
         decoded_k = CurrentFormatter.formatter.decode(property_name=k)
@@ -206,13 +256,18 @@ def _from_json(cls: Type[_T], data: Dict[str, Any]) -> object:
         new_key = None
         if decoded_k not in klass_properties:
             for p, pi in klass_properties.items():
-                if pi.custom_names.get(SerializationType.JSON, None) == decoded_k:
+                if pi.custom_names.get(SerializationType.JSON, None) == k:
                     new_key = p
         else:
             new_key = decoded_k
 
         if new_key is None:
-            raise ValueError(f'Unexpected key {k} in data being serialized to {cls.__module__}.{cls.__qualname__}')
+            logger.error(
+                f'Unexpected key {k}/{decoded_k} in data being serialized to {cls.__module__}.{cls.__qualname__}'
+            )
+            raise ValueError(
+                f'Unexpected key {k}/{decoded_k} in data being serialized to {cls.__module__}.{cls.__qualname__}'
+            )
 
         del (_data[k])
         _data[new_key] = v
@@ -222,36 +277,45 @@ def _from_json(cls: Type[_T], data: Dict[str, Any]) -> object:
         if not prop_info:
             raise ValueError(f'No Prop Info for {k} in {cls}')
 
-        if prop_info.custom_type:
-            if prop_info.is_helper_type():
-                _data[k] = prop_info.custom_type.deserialize(v)
-            else:
-                _data[k] = prop_info.custom_type(v)
-        elif prop_info.is_array:
-            items = []
-            for j in v:
-                if not prop_info.is_primitive_type():
-                    items.append(prop_info.concrete_type.from_json(data=j))
+        try:
+            if prop_info.custom_type:
+                if prop_info.is_helper_type():
+                    _data[k] = prop_info.custom_type.deserialize(v)
                 else:
-                    items.append(prop_info.concrete_type(j))
-            _data[k] = items
-        elif prop_info.is_enum:
-            _data[k] = prop_info.concrete_type(v)
-        elif not prop_info.is_primitive_type():
-            global_klass_name = f'{prop_info.concrete_type.__module__}.{prop_info.concrete_type.__name__}'
-            if global_klass_name in ObjectMetadataLibrary.klass_mappings:
-                _data[k] = prop_info.concrete_type.from_json(data=v)
-            else:
+                    _data[k] = prop_info.custom_type(v)
+            elif prop_info.is_array:
+                items = []
+                for j in v:
+                    if not prop_info.is_primitive_type() and not prop_info.is_enum:
+                        items.append(prop_info.concrete_type.from_json(data=j))
+                    else:
+                        items.append(prop_info.concrete_type(j))
+                _data[k] = items  # type: ignore
+            elif prop_info.is_enum:
                 _data[k] = prop_info.concrete_type(v)
+            elif not prop_info.is_primitive_type():
+                global_klass_name = f'{prop_info.concrete_type.__module__}.{prop_info.concrete_type.__name__}'
+                if global_klass_name in ObjectMetadataLibrary.klass_mappings:
+                    _data[k] = prop_info.concrete_type.from_json(data=v)
+                else:
+                    _data[k] = prop_info.concrete_type(v)
+        except AttributeError as e:
+            logging.error(f'There was an AttributeError deserializing JSON to {cls}.{os.linesep}'
+                          f'The Property is: {prop_info}{os.linesep}'
+                          f'The Value was: {v}{os.linesep}'
+                          f'Exception: {e}{os.linesep}')
+            raise AttributeError(
+                f'There was an AttributeError deserializing JSON to {cls} the Property {prop_info}: {e}'
+            )
 
     logging.debug(f'Creating {cls} from {_data}')
 
     return cls(**_data)
 
 
-def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None,
+def _as_xml(self: _T, view_: Optional[Type[_T]] = None, as_string: bool = True, element_name: Optional[str] = None,
             xmlns: Optional[str] = None) -> Union[ElementTree.Element, str]:
-    logging.debug(f'Dumping {self} to XML...')
+    logging.debug(f'Dumping {self} to XML with view {view_}...')
 
     this_e_attributes = {}
     klass_qualified_name = f'{self.__module__}.{self.__class__.__qualname__}'
@@ -266,12 +330,13 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
             continue
         new_key = BaseNameFormatter.decode_handle_python_builtins_and_keywords(name=new_key)
 
-        # Ignore Nones
-        if not v:
-            continue
-
         if new_key in serializable_property_info:
-            prop_info = serializable_property_info.get(new_key)
+            prop_info = cast('ObjectMetadataLibrary.SerializableProperty', serializable_property_info.get(new_key))
+
+            if not _allow_property_for_view(prop_info=prop_info, view_=view_, value_=v):
+                # Skip as rendering for a view and this Property is not registered form this View
+                continue
+
             if prop_info and prop_info.is_xml_attribute:
                 new_key = prop_info.custom_names.get(SerializationType.XML, new_key)
                 if CurrentFormatter.formatter:
@@ -291,12 +356,16 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
 
     # Handle remaining Properties that will be sub elements
     for k, prop_info in serializable_property_info.items():
+        # Skip if rendering for a View and this Property is not designated for this View
         v = getattr(self, k)
 
-        # Ignore None values by default
-        if v is None:
+        if not _allow_property_for_view(prop_info=prop_info, view_=view_, value_=v):
+            # Skip as rendering for a view and this Property is not registered form this View
             continue
 
+        if v is None:
+            v = prop_info.get_none_value_for_view(view_=view_)
+
         new_key = BaseNameFormatter.decode_handle_python_builtins_and_keywords(name=k)
 
         if not prop_info:
@@ -305,6 +374,10 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
         if not prop_info.is_xml_attribute:
             new_key = prop_info.custom_names.get(SerializationType.XML, new_key)
 
+            if v is None:
+                ElementTree.SubElement(this_e, _namespace_element_name(tag_name=new_key, xmlns=xmlns))
+                continue
+
             if new_key == '.':
                 this_e.text = str(v)
                 continue
@@ -321,14 +394,16 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
             elif prop_info.is_array and prop_info.xml_array_config:
                 _array_type, nested_key = prop_info.xml_array_config
                 nested_key = _namespace_element_name(tag_name=nested_key, xmlns=xmlns)
-                if _array_type and _array_type == XmlArraySerializationType.NESTED and len(v) > 0:
+                if _array_type and _array_type == XmlArraySerializationType.NESTED:
                     nested_e = ElementTree.SubElement(this_e, new_key)
                 else:
                     nested_e = this_e
 
                 for j in v:
-                    if not prop_info.is_primitive_type():
-                        nested_e.append(j.as_xml(as_string=False, element_name=nested_key, xmlns=xmlns))
+                    if not prop_info.is_primitive_type() and not prop_info.is_enum:
+                        nested_e.append(j.as_xml(view_=view_, as_string=False, element_name=nested_key, xmlns=xmlns))
+                    elif prop_info.is_enum:
+                        ElementTree.SubElement(nested_e, nested_key).text = str(j.value)
                     elif prop_info.concrete_type in (float, int):
                         ElementTree.SubElement(nested_e, nested_key).text = str(j)
                     elif prop_info.concrete_type is bool:
@@ -342,10 +417,13 @@ def _as_xml(self: _T, as_string: bool = True, element_name: Optional[str] = None
                 global_klass_name = f'{prop_info.concrete_type.__module__}.{prop_info.concrete_type.__name__}'
                 if global_klass_name in ObjectMetadataLibrary.klass_mappings:
                     # Handle other Serializable Classes
-                    this_e.append(v.as_xml(as_string=False, element_name=new_key, xmlns=xmlns))
+                    this_e.append(v.as_xml(view_=view_, as_string=False, element_name=new_key, xmlns=xmlns))
                 else:
                     # Handle properties that have a type that is not a Python Primitive (e.g. int, float, str)
-                    ElementTree.SubElement(this_e, new_key).text = str(v)
+                    if prop_info.string_format:
+                        ElementTree.SubElement(this_e, new_key).text = f'{v:{prop_info.string_format}}'
+                    else:
+                        ElementTree.SubElement(this_e, new_key).text = str(v)
             elif prop_info.concrete_type in (float, int):
                 ElementTree.SubElement(this_e, new_key).text = str(v)
             elif prop_info.concrete_type is bool:
@@ -443,45 +521,56 @@ def _from_xml(cls: Type[_T], data: Union[TextIOWrapper, ElementTree.Element],
         if not prop_info:
             raise ValueError(f'{decoded_k} is not a known Property for {cls.__module__}.{cls.__qualname__}')
 
-        if prop_info.custom_type:
-            if prop_info.is_helper_type():
-                _data[decoded_k] = prop_info.custom_type.deserialize(child_e.text)
-            else:
-                _data[decoded_k] = prop_info.custom_type(child_e.text)
-        elif prop_info.is_array and prop_info.xml_array_config:
-            array_type, nested_name = prop_info.xml_array_config
+        try:
+            if prop_info.custom_type:
+                if prop_info.is_helper_type():
+                    _data[decoded_k] = prop_info.custom_type.deserialize(child_e.text)
+                else:
+                    _data[decoded_k] = prop_info.custom_type(child_e.text)
+            elif prop_info.is_array and prop_info.xml_array_config:
+                array_type, nested_name = prop_info.xml_array_config
 
-            if decoded_k not in _data:
-                _data[decoded_k] = []
+                if decoded_k not in _data:
+                    _data[decoded_k] = []
 
-            if array_type == XmlArraySerializationType.NESTED:
-                for sub_child_e in child_e:
+                if array_type == XmlArraySerializationType.NESTED:
+                    for sub_child_e in child_e:
+                        if not prop_info.is_primitive_type() and not prop_info.is_enum:
+                            _data[decoded_k].append(prop_info.concrete_type.from_xml(
+                                data=sub_child_e, default_namespace=default_namespace)
+                            )
+                        else:
+                            _data[decoded_k].append(prop_info.concrete_type(sub_child_e.text))
+                else:
                     if not prop_info.is_primitive_type():
                         _data[decoded_k].append(prop_info.concrete_type.from_xml(
-                            data=sub_child_e, default_namespace=default_namespace)
+                            data=child_e, default_namespace=default_namespace)
                         )
                     else:
-                        _data[decoded_k].append(prop_info.concrete_type(sub_child_e.text))
-            else:
-                if not prop_info.is_primitive_type():
-                    _data[decoded_k].append(prop_info.concrete_type.from_xml(
-                        data=child_e, default_namespace=default_namespace)
+                        _data[decoded_k].append(prop_info.concrete_type(child_e.text))
+            elif prop_info.is_enum:
+                _data[decoded_k] = prop_info.concrete_type(child_e.text)
+            elif not prop_info.is_primitive_type():
+                global_klass_name = f'{prop_info.concrete_type.__module__}.{prop_info.concrete_type.__name__}'
+                if global_klass_name in ObjectMetadataLibrary.klass_mappings:
+                    _data[decoded_k] = prop_info.concrete_type.from_xml(
+                        data=child_e, default_namespace=default_namespace
                     )
                 else:
-                    _data[decoded_k].append(prop_info.concrete_type(child_e.text))
-        elif prop_info.is_enum:
-            _data[decoded_k] = prop_info.concrete_type(child_e.text)
-        elif not prop_info.is_primitive_type():
-            global_klass_name = f'{prop_info.concrete_type.__module__}.{prop_info.concrete_type.__name__}'
-            if global_klass_name in ObjectMetadataLibrary.klass_mappings:
-                _data[decoded_k] = prop_info.concrete_type.from_xml(data=child_e, default_namespace=default_namespace)
+                    _data[decoded_k] = prop_info.concrete_type(child_e.text)
             else:
-                _data[decoded_k] = prop_info.concrete_type(child_e.text)
-        else:
-            if prop_info.concrete_type == bool:
-                _data[decoded_k] = True if str(child_e.text) in (1, 'true') else False
-            else:
-                _data[decoded_k] = prop_info.concrete_type(child_e.text)
+                if prop_info.concrete_type == bool:
+                    _data[decoded_k] = True if str(child_e.text) in (1, 'true') else False
+                else:
+                    _data[decoded_k] = prop_info.concrete_type(child_e.text)
+        except AttributeError as e:
+            logging.error(f'There was an AttributeError deserializing JSON to {cls}.{os.linesep}'
+                          f'The Property is: {prop_info}{os.linesep}'
+                          f'The Value was: {v}{os.linesep}'
+                          f'Exception: {e}{os.linesep}')
+            raise AttributeError(
+                f'There was an AttributeError deserializing XML to {cls} the Property {prop_info}: {e}'
+            )
 
     logging.debug(f'Creating {cls} from {_data}')
 
@@ -502,11 +591,16 @@ class ObjectMetadataLibrary:
     serialization and deserialization.
     """
     _deferred_property_type_parsing: Dict[str, Set['ObjectMetadataLibrary.SerializableProperty']] = {}
+    _klass_views: Dict[str, Type[Any]] = {}
     _klass_property_array_config: Dict[str, Tuple[XmlArraySerializationType, str]] = {}
     _klass_property_attributes: Set[str] = set()
+    _klass_property_include_none: Dict[str, Set[Tuple[_Klass, Any]]] = {}
     _klass_property_names: Dict[str, Dict[SerializationType, str]] = {}
+    _klass_property_string_formats: Dict[str, str] = {}
     _klass_property_types: Dict[str, Type[Any]] = {}
+    _klass_property_views: Dict[str, Set[_Klass]] = {}
     _klass_property_xml_sequence: Dict[str, int] = {}
+    custom_enum_klasses: Set[_Klass] = set()
     klass_mappings: Dict[str, 'ObjectMetadataLibrary.SerializableClass'] = {}
     klass_property_mappings: Dict[str, Dict[str, 'ObjectMetadataLibrary.SerializableProperty']] = {}
 
@@ -557,13 +651,16 @@ class ObjectMetadataLibrary:
         """
 
         _ARRAY_TYPES = ('List', 'Set', 'SortedSet')
+        _DEFAULT_XML_SEQUENCE = 100
         _SORTED_CONTAINERS_TYPES = {'SortedList': List, 'SortedSet': Set}
         _PRIMITIVE_TYPES = (bool, int, float, str)
 
         def __init__(self, *, prop_name: str, prop_type: Any, custom_names: Dict[SerializationType, str],
-                     custom_type: Optional[Any] = None, is_xml_attribute: bool = False,
+                     custom_type: Optional[Any] = None, include_none_config: Optional[Set[Tuple[_Klass, Any]]] = None,
+                     is_xml_attribute: bool = False, string_format_: Optional[str] = None,
+                     views: Optional[Iterable[_Klass]] = None,
                      xml_array_config: Optional[Tuple[XmlArraySerializationType, str]] = None,
-                     xml_sequence: Optional[int] = None) -> None:
+                     xml_sequence_: Optional[int] = None) -> None:
             self._name = prop_name
             self._custom_names = custom_names
             self._type_ = None
@@ -572,9 +669,17 @@ class ObjectMetadataLibrary:
             self._is_enum = False
             self._is_optional = False
             self._custom_type = custom_type
+            if include_none_config is not None:
+                self._include_none = True
+                self._include_none_views = include_none_config
+            else:
+                self._include_none = False
+                self._include_none_views = set()
             self._is_xml_attribute = is_xml_attribute
+            self._string_format = string_format_
+            self._views = set(views or [])
             self._xml_array_config = xml_array_config
-            self._xml_sequence = xml_sequence or 100
+            self._xml_sequence = xml_sequence_ or self._DEFAULT_XML_SEQUENCE
 
             self._deferred_type_parsing = False
             self._parse_type(type_=prop_type)
@@ -602,10 +707,40 @@ class ObjectMetadataLibrary:
         def custom_type(self) -> Optional[Any]:
             return self._custom_type
 
+        @property
+        def include_none(self) -> bool:
+            return self._include_none
+
+        @property
+        def include_none_views(self) -> Set[Tuple[_Klass, Any]]:
+            return self._include_none_views
+
+        def include_none_for_view(self, view_: _Klass) -> bool:
+            for _v, _a in self._include_none_views:
+                if _v == view_:
+                    return True
+
+            return False
+
+        def get_none_value_for_view(self, view_: Optional[Type[_Klass]]) -> Any:
+            if view_:
+                for _v, _a in self._include_none_views:
+                    if _v == view_:
+                        return _a
+            return None
+
         @property
         def is_xml_attribute(self) -> bool:
             return self._is_xml_attribute
 
+        @property
+        def string_format(self) -> Optional[str]:
+            return self._string_format
+
+        @property
+        def views(self) -> Set[_Klass]:
+            return self._views
+
         @property
         def xml_array_config(self) -> Optional[Tuple[XmlArraySerializationType, str]]:
             return self._xml_array_config
@@ -626,6 +761,10 @@ class ObjectMetadataLibrary:
         def xml_sequence(self) -> int:
             return self._xml_sequence
 
+        def get_none_value(self, view_: Optional[_Klass] = None) -> Any:
+            if not self.include_none:
+                raise ValueError('No None Value for property that is not include_none')
+
         def is_helper_type(self) -> bool:
             if inspect.isclass(self.custom_type):
                 return issubclass(self.custom_type, BaseHelper)
@@ -662,11 +801,17 @@ class ObjectMetadataLibrary:
                             self._concrete_type = eval(str(results.get("array_of")))
                         except NameError:
                             # Likely a class that is missing its fully qualified name
-                            _k = None
+                            _k: Optional[Any] = None
                             for _k_name, _oml_sc in ObjectMetadataLibrary.klass_mappings.items():
                                 if _oml_sc.name == results.get("array_of"):
                                     _k = _oml_sc.klass
 
+                            if _k is None:
+                                # Perhaps a custom ENUM?
+                                for _enum_klass in ObjectMetadataLibrary.custom_enum_klasses:
+                                    if _enum_klass.__name__ == results.get("array_of"):
+                                        _k = _enum_klass
+
                             if _k is None:
                                 self._type_ = type_  # type: ignore
                                 self._deferred_type_parsing = True
@@ -676,7 +821,7 @@ class ObjectMetadataLibrary:
                                 return
 
                             self._type_ = mapped_array_type[_k]  # type: ignore
-                            self._concrete_type = _k
+                            self._concrete_type = _k  # type: ignore
                 else:
                     raise ValueError(f'Unable to handle Property with declared type: {type_}')
             else:
@@ -747,6 +892,11 @@ class ObjectMetadataLibrary:
     def is_property(cls, o: object) -> bool:
         return isinstance(o, property)
 
+    @classmethod
+    def register_enum(cls, klass: _T) -> _T:
+        cls.custom_enum_klasses.add(klass)
+        return klass
+
     @classmethod
     def register_klass(cls, klass: _T, custom_name: Optional[str],
                        serialization_types: Iterable[SerializationType],
@@ -755,13 +905,13 @@ class ObjectMetadataLibrary:
             return klass
 
         cls.klass_mappings.update({
-            f'{klass.__module__}.{klass.__qualname__}': ObjectMetadataLibrary.SerializableClass(  # type: ignore
+            f'{klass.__module__}.{klass.__qualname__}': ObjectMetadataLibrary.SerializableClass(
                 klass=klass, serialization_types=serialization_types,
                 ignore_during_deserialization=ignore_during_deserialization
             )
         })
 
-        qualified_class_name = f'{klass.__module__}.{klass.__qualname__}'  # type: ignore
+        qualified_class_name = f'{klass.__module__}.{klass.__qualname__}'
         cls.klass_property_mappings.update({qualified_class_name: {}})
         logging.debug(f'Registering Class {qualified_class_name} with custom name {custom_name}')
         for name, o in inspect.getmembers(klass, ObjectMetadataLibrary.is_property):
@@ -774,11 +924,20 @@ class ObjectMetadataLibrary:
                     custom_names=ObjectMetadataLibrary._klass_property_names.get(qualified_property_name, {}),
                     prop_type=prop_arg_specs.annotations.get('return', None),
                     custom_type=ObjectMetadataLibrary._klass_property_types.get(qualified_property_name, None),
+                    include_none_config=ObjectMetadataLibrary._klass_property_include_none.get(
+                        qualified_property_name, None
+                    ),
                     is_xml_attribute=(qualified_property_name in ObjectMetadataLibrary._klass_property_attributes),
+                    string_format_=ObjectMetadataLibrary._klass_property_string_formats.get(
+                        qualified_property_name, None
+                    ),
+                    views=ObjectMetadataLibrary._klass_property_views.get(
+                        qualified_property_name, None
+                    ),
                     xml_array_config=ObjectMetadataLibrary._klass_property_array_config.get(
                         qualified_property_name, None
                     ),
-                    xml_sequence=ObjectMetadataLibrary._klass_property_xml_sequence.get(qualified_property_name, 100)
+                    xml_sequence_=ObjectMetadataLibrary._klass_property_xml_sequence.get(qualified_property_name, 100)
                 )
             })
 
@@ -800,10 +959,14 @@ class ObjectMetadataLibrary:
     @classmethod
     def register_custom_json_property_name(cls, qual_name: str, json_property_name: str) -> None:
         if qual_name in cls._klass_property_names:
-            cls._klass_property_names[qual_name].update({SerializationType.JSON: json_property_name})
+            cls._klass_property_names.get(qual_name, {}).update({SerializationType.JSON: json_property_name})
         else:
             cls._klass_property_names.update({qual_name: {SerializationType.JSON: json_property_name}})
 
+    @classmethod
+    def register_custom_string_format(cls, qual_name: str, string_format: str) -> None:
+        cls._klass_property_string_formats.update({qual_name: string_format})
+
     @classmethod
     def register_custom_xml_property_name(cls, qual_name: str, xml_property_name: str) -> None:
         if qual_name in cls._klass_property_names:
@@ -811,6 +974,30 @@ class ObjectMetadataLibrary:
         else:
             cls._klass_property_names.update({qual_name: {SerializationType.XML: xml_property_name}})
 
+    @classmethod
+    def register_klass_view(cls, klass: _T, view_: Type[Any]) -> _T:
+        ObjectMetadataLibrary._klass_views.update({
+            f'{klass.__module__}.{klass.__qualname__}': view_
+        })
+        return klass
+
+    @classmethod
+    def register_property_include_none(cls, qual_name: str, view_: Optional[_Klass] = None,
+                                       none_value: Optional[Any] = None) -> None:
+        if qual_name not in cls._klass_property_include_none:
+            cls._klass_property_include_none.update({qual_name: set()})
+        if view_:
+            cls._klass_property_include_none.get(qual_name, set()).add((view_, none_value))
+        else:
+            cls._klass_property_include_none.get(qual_name, set()).add((_Klass, none_value))
+
+    @classmethod
+    def register_property_view(cls, qual_name: str, view_: _T) -> None:
+        if qual_name not in ObjectMetadataLibrary._klass_property_views:
+            ObjectMetadataLibrary._klass_property_views.update({qual_name: {view_}})
+        else:
+            ObjectMetadataLibrary._klass_property_views.get(qual_name, set()).add(view_)
+
     @classmethod
     def register_xml_property_array_config(cls, qual_name: str,
                                            array_type: XmlArraySerializationType, child_name: str) -> None:
@@ -829,10 +1016,24 @@ class ObjectMetadataLibrary:
         cls._klass_property_types.update({qual_name: mapped_type})
 
 
-def serializable_class(cls: Optional[Type[_T]] = None, *, name: Optional[str] = None,
+def serializable_enum(cls: Optional[Any] = None) -> Any:
+    def wrap(kls: Type[_T]) -> Type[_T]:
+        ObjectMetadataLibrary.register_enum(klass=kls)
+        return kls
+
+    # See if we're being called as @enum or @enum().
+    if cls is None:
+        # We're called with parens.
+        return wrap
+
+    # We're called as @register_klass without parens.
+    return wrap(cls)
+
+
+def serializable_class(cls: Optional[Any] = None, *, name: Optional[str] = None,
                        serialization_types: Optional[Iterable[SerializationType]] = None,
                        ignore_during_deserialization: Optional[Iterable[str]] = None
-                       ) -> Union[Callable[[Any], Type[_T]], Type[_T]]:
+                       ) -> Any:
     """
     Decorator used to tell ``serializable`` that a class is to be included in (de-)serialization.
 
@@ -861,7 +1062,7 @@ def serializable_class(cls: Optional[Type[_T]] = None, *, name: Optional[str] =
     return wrap(cls)
 
 
-def type_mapping(type_: Any) -> Callable[[_F], _F]:
+def type_mapping(type_: _T) -> Callable[[_F], _F]:
     """
     Deoc
     :param type_:
@@ -883,6 +1084,22 @@ def type_mapping(type_: Any) -> Callable[[_F], _F]:
     return outer
 
 
+def include_none(view_: Optional[Type[_T]] = None, none_value: Optional[Any] = None) -> Callable[[_F], _F]:
+    def outer(f: _F) -> _F:
+        logger.debug(f'Registering {f.__module__}.{f.__qualname__} to include None for view: {view_}')
+        ObjectMetadataLibrary.register_property_include_none(
+            qual_name=f'{f.__module__}.{f.__qualname__}', view_=view_, none_value=none_value
+        )
+
+        @functools.wraps(f)
+        def inner(*args: Any, **kwargs: Any) -> Any:
+            return f(*args, **kwargs)
+
+        return cast(_F, inner)
+
+    return outer
+
+
 def json_name(name: str) -> Callable[[_F], _F]:
     def outer(f: _F) -> _F:
         logger.debug(f'Registering {f.__module__}.{f.__qualname__} with JSON name: {name}')
@@ -899,6 +1116,38 @@ def json_name(name: str) -> Callable[[_F], _F]:
     return outer
 
 
+def string_format(format_: str) -> Callable[[_F], _F]:
+    def outer(f: _F) -> _F:
+        logger.debug(f'Registering {f.__module__}.{f.__qualname__} with String Format: {format_}')
+        ObjectMetadataLibrary.register_custom_string_format(
+            qual_name=f'{f.__module__}.{f.__qualname__}', string_format=format_
+        )
+
+        @functools.wraps(f)
+        def inner(*args: Any, **kwargs: Any) -> Any:
+            return f(*args, **kwargs)
+
+        return cast(_F, inner)
+
+    return outer
+
+
+def view(view_: ViewType) -> Callable[[_F], _F]:
+    def outer(f: _F) -> _F:
+        logger.debug(f'Registering {f.__module__}.{f.__qualname__} with View: {view_}')
+        ObjectMetadataLibrary.register_property_view(
+            qual_name=f'{f.__module__}.{f.__qualname__}', view_=view_
+        )
+
+        @functools.wraps(f)
+        def inner(*args: Any, **kwargs: Any) -> Any:
+            return f(*args, **kwargs)
+
+        return cast(_F, inner)
+
+    return outer
+
+
 def xml_attribute() -> Callable[[_F], _F]:
     def outer(f: _F) -> _F:
         logger.debug(f'Registering {f.__module__}.{f.__qualname__} as XML attribute')
